@@ -48,8 +48,8 @@ class AAS_URLInterface(AsyncAPISpider):
     def refresh(self):
         self.res={}
 
-    async def request(self,url,headers={},params={},ssl=False,allow_redirects=True):
-        return self._request_async(url,headers=headers,params=params,ssl=ssl,allow_redirects=allow_redirects)
+    async def request(self,url,decoding='utf-8',headers={},params={},ssl=False,allow_redirects=True):
+        return self._request_async(url,headers=headers,params=params,ssl=ssl,allow_redirects=allow_redirects,decoding=decoding)
         
     async def map(self,urls,load=False):
         await self._concurrent_gather(self.s,*urls)
